# Security Policy

Security is very important for Fastrapi and its community. 🔒

Learn more about it below. 👇

## Versions

The latest version of Fastrapi is supported.

You are encouraged to **write tests** for your Rust and Python bindings, and update your dependencies frequently after ensuring your tests pass. This way you will benefit from the latest features, bug fixes, and **security fixes**.

You can learn more about Rust and PyO3 versions and how to pin and upgrade them for your project in their respective docs:
- [PyO3 Versions](https://pyo3.rs/)
- [Axum Versions](https://docs.rs/axum/latest/axum/)

## Reporting a Vulnerability

If you think you found a vulnerability, and even if you are not sure about it, please report it right away by sending an email to: security@fastrapi.dev.  

Please try to be as explicit as possible, describing all steps, example code, and environment setup to reproduce the security issue.  

I (the author, [@ppmpreetham](https://x.com/ppmpreetham)) will review it thoroughly and get back to you.

## Public Discussions

Please restrain from publicly discussing a potential security vulnerability. 🙊

It's better to discuss privately and try to find a solution first, to limit the potential impact as much as possible.

---

Thanks for your help!

The Fastrapi community and I thank you for that. 🙇